@@ -76,7 +76,7 @@ if (getRversion() >= "3.1.0") {
 #' @section Parsing and Checking Code:
 #'
 #' The \code{simInit} function will attempt to find usage of sim$xxx
-#' or sim[['xxx']] on either side of the assignement "<-" operator.
+#' or sim[['xxx']] on either side of the assignment "<-" operator.
 #' It will compare these to the module metadata, specifically
 #' \code{inputObjects} for cases where objects or "gotten" from the
 #' simList and \code{outputObjects} for cases where objects are
@@ -88,7 +88,7 @@ if (getRversion() >= "3.1.0") {
 #'
 #' \emph{This code checking is young and may get false positives and
 #' false negatives -- i.e., miss things}. It also takes computational
-#' time, which may be undesireable in operational code.
+#' time, which may be undesirable in operational code.
 #' To turn off checking (i.e.,
 #' if there are too many false positives and negatives), set
 #' the option \code{spades.moduleCodeChecks} to \code{FALSE},
@@ -96,20 +96,21 @@ if (getRversion() >= "3.1.0") {
 #'
 #' @section Caching:
 #'
-#' Using caching with \code{SpaDES} is vital when building re-useable and reproducible
-#' content. Please see the vignette dedicated to this topic. See
-#' \url{https://CRAN.R-project.org/package=SpaDES/vignettes/iii-cache.html}
+#' Using caching with \code{SpaDES} is vital when building re-useble and reproducible content.
+#' Please see the vignette dedicated to this topic.
+#' See \url{https://CRAN.R-project.org/package=SpaDES/vignettes/iii-cache.html}
 #'
 #' @note
 #' The user can opt to run a simpler \code{simInit} call without inputs, outputs, and times.
-#' These can be added later with the accessor methods (See example). These are not required for initializing the
-#' simulation via simInit. \code{modules}, \code{paths}, \code{params}, and \code{objects}
-#' are all needed for successful initialization.
+#' These can be added later with the accessor methods (See example).
+#' These are not required for initializing the simulation via simInit.
+#' All of \code{modules}, \code{paths}, \code{params}, and \code{objects} are needed
+#' for successful initialization.
 #'
 #' @param times A named list of numeric simulation start and end times
 #'        (e.g., \code{times = list(start = 0.0, end = 10.0)}).
 #'
-#' @param params A list of lists of the form list(moduleName=list(param1=value, param2=value)).
+#' @param params A list of lists of the form \code{list(moduleName=list(param1=value, param2=value))}.
 #' See details.
 #'
 #' @param modules A named list of character strings specifying the names
@@ -176,7 +177,7 @@ if (getRversion() >= "3.1.0") {
 #' @rdname simInit
 #'
 #' @references Matloff, N. (2011). The Art of R Programming (ch. 7.8.3).
-#'             San Fransisco, CA: No Starch Press, Inc..
+#'             San Francisco, CA: No Starch Press, Inc..
 #'             Retrieved from \url{https://www.nostarch.com/artofr.htm}
 #'
 #' @examples
@@ -342,6 +343,12 @@ setMethod(
 
     names(modules) <- unlist(modules)
 
+    # Check that modules exist in paths$modulePath
+    moduleDirsExist <- dir.exists(file.path(paths$modulePath, unlist(modules)))
+    if (!isTRUE(all(moduleDirsExist))) {
+      stop("These modules: ", unlist(modules)[!moduleDirsExist], " , don't exist in ", paths$modulePath)
+    }
+
     # identify childModules, recursively
     childModules <- .identifyChildModules(sim = sim, modules = modules)
     modules <- as.list(unique(unlist(childModules))) # flat list of all modules
@@ -367,7 +374,12 @@ setMethod(
     reqdPkgs <- packages(modules=unlist(modules), paths = paths(sim)$modulePath,
                          envir = sim@.envir[[".parsedFiles"]])
     if (length(unlist(reqdPkgs))) {
-      Require(c(unique(unlist(reqdPkgs), "SpaDES.core")))
+      allPkgs <- c(unique(unlist(reqdPkgs), "SpaDES.core"))
+      if (getOption("spades.useRequire")) {
+        Require(allPkgs)
+      } else {
+        loadedPkgs <- lapply(allPkgs, require, character.only = TRUE)
+      }
     }
 
     ## timeunit is needed before all parsing of modules.
@@ -823,7 +835,7 @@ simInitAndSpades <- function(...) {
 
 #' Identify module names up to a given recursive level
 #'
-#' With children, parents, grandparents, etc, there can be severl "layers" of recursion.
+#' With children, parents, grandparents, etc.; there can be several "layers" of recursion.
 #' Some functions need to evaluate the outer level for a value, if found, they don't need
 #' to proceed further. If not found, increment one more level of recursion, etc.
 #'
